@@ -1,22 +1,18 @@
 /*
- *  Copyright (C) 2004-2024 Savoir-faire Linux Inc.
+ *  Copyright (C) 2004-2025 Savoir-faire Linux Inc.
  *
- *  Author: Philippe Proulx <philippe.proulx@savoirfairelinux.com>
- *  Author: Guillaume Roguez <Guillaume.Roguez@savoirfairelinux.com>
- *
- *  This program is free software; you can redistribute it and/or modify
+ *  This program is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
- *  the Free Software Foundation; either version 3 of the License, or
+ *  the Free Software Foundation, either version 3 of the License, or
  *  (at your option) any later version.
  *
  *  This program is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
  *  GNU General Public License for more details.
  *
  *  You should have received a copy of the GNU General Public License
- *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301 USA.
+ *  along with this program. If not, see <https://www.gnu.org/licenses/>.
  */
 #ifndef LIBJAMI_H
 #define LIBJAMI_H
@@ -39,6 +35,7 @@ namespace libjami {
 enum InitFlag {
     LIBJAMI_FLAG_DEBUG = 1 << 0,
     LIBJAMI_FLAG_CONSOLE_LOG = 1 << 1,
+    LIBJAMI_FLAG_SYSLOG = 1 << 3,
     LIBJAMI_FLAG_AUTOANSWER = 1 << 2,
     LIBJAMI_FLAG_IOS_EXTENSION = 1 << 4,
     LIBJAMI_FLAG_NO_LOCAL_AUDIO = 1 << 6,
@@ -56,7 +53,12 @@ LIBJAMI_PUBLIC const char* version() noexcept;
 /**
  * Return the target platform (OS) as a string.
  */
-LIBJAMI_PUBLIC const char* platform() noexcept;
+LIBJAMI_PUBLIC std::string_view platform() noexcept;
+
+/**
+ * Return the target architecture as a string.
+ */
+LIBJAMI_PUBLIC std::string_view arch() noexcept;
 
 /**
  * Initialize globals, create underlaying daemon.
